@@ -21,6 +21,7 @@
 #include "nsString.h"
 #include "nsCOMPtr.h"
 #include "nsWeakReference.h"
+#include "mozilla/net/Dictionary.h"
 
 #include "nsIHttpProtocolHandler.h"
 #include "nsIObserver.h"
@@ -116,8 +117,12 @@ class nsHttpHandler final : public nsIHttpProtocolHandler,
 
   static already_AddRefed<nsHttpHandler> GetInstance();
 
+  [[nodiscard]] nsresult AddAcceptAndDictionaryHeaders(
+      nsIURI* aURI, ExtContentPolicyType aType, nsHttpRequestHead* aRequest,
+      bool aSecure, nsHttpChannel* aChan, void (*aSuspend)(nsHttpChannel*),
+      const std::function<bool(bool, DictionaryCacheEntry*)>& aCallback);
   [[nodiscard]] nsresult AddStandardRequestHeaders(
-      nsHttpRequestHead*, bool isSecure,
+      nsHttpRequestHead*, nsIURI* aURI, bool aIsHTTPS,
       ExtContentPolicyType aContentPolicyType,
       bool aShouldResistFingerprinting);
   [[nodiscard]] nsresult AddConnectionHeader(nsHttpRequestHead*, uint32_t caps);
@@ -526,7 +531,8 @@ class nsHttpHandler final : public nsIHttpProtocolHandler,
   void PrefsChanged(const char* pref);
 
   [[nodiscard]] nsresult SetAcceptLanguages();
-  [[nodiscard]] nsresult SetAcceptEncodings(const char*, bool mIsSecure);
+  [[nodiscard]] nsresult SetAcceptEncodings(const char*, bool aIsSecure,
+                                            bool aDictionary);
 
   [[nodiscard]] nsresult InitConnectionMgr();
 
@@ -563,6 +569,9 @@ class nsHttpHandler final : public nsIHttpProtocolHandler,
 
   UniquePtr<AltSvcCache> mAltSvcCache;
 
+  // Pointer to DictionaryCache singleton
+  RefPtr<DictionaryCache> mDictionaryCache;
+
   //
   // prefs
   //
@@ -623,6 +632,7 @@ class nsHttpHandler final : public nsIHttpProtocolHandler,
   nsCString mAcceptLanguages;
   nsCString mHttpAcceptEncodings;
   nsCString mHttpsAcceptEncodings;
+  nsCString mDictionaryAcceptEncodings;
 
   nsCString mDefaultSocketType;
 
